[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible: fixup d59690b, correctly call _master_wrapper.sh

Holger Levsen holger at moszumanska.debian.org
Wed Sep 9 13:53:20 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 9929536a89a464c0c763aae189e33865a282885f
Author: Holger Levsen <holger at layer-acht.org>
Date:   Wed Sep 9 15:52:44 2015 +0200

    reproducible: fixup d59690b, correctly call _master_wrapper.sh
---
 bin/jenkins_node_wrapper.sh    | 2 +-
 bin/reproducible_nodes_info.sh | 7 +++++--
 2 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/bin/jenkins_node_wrapper.sh b/bin/jenkins_node_wrapper.sh
index 054ea2a..cc47736 100755
--- a/bin/jenkins_node_wrapper.sh
+++ b/bin/jenkins_node_wrapper.sh
@@ -65,7 +65,7 @@ elif [[ "$*" =~ rebootstrap_.* ]] ; then
 	REBOOTSTRAPSH="/srv/jenkins/bin/rebootstrap.sh $@"
 	export LC_ALL=C
 	exec $REBOOTSTRAPSH; croak "Exec failed";
-elif [ "$1" = "/srv/jenkins/bin/reproducible_info" ] ; then
+elif [ "$1" = "/srv/jenkins/bin/reproducible_info.sh" ] ; then
 	exec /srv/jenkins/bin/reproducible_info.sh "$2" ; croak "Exec failed";
 elif [ "$1" = "/srv/jenkins/bin/reproducible_build.sh" ] && ( [ "$2" = "1" ] || [ "$2" = "2" ] ) ; then
 	exec /srv/jenkins/bin/reproducible_build.sh "$2" "$3" "$4" "$5" ; croak "Exec failed";
diff --git a/bin/reproducible_nodes_info.sh b/bin/reproducible_nodes_info.sh
index 6c6ab7e..fbeeccb 100755
--- a/bin/reproducible_nodes_info.sh
+++ b/bin/reproducible_nodes_info.sh
@@ -16,8 +16,11 @@ TMPFILE_SRC=$(mktemp)
 TMPFILE_NODE=$(mktemp)
 
 for NODE in bpi0-armhf-rb.debian.net hb0-armhf-rb.debian.net wbq0-armhf-rb.debian.net cbxi4pro0-armhf-rb.debian.net profitbricks-build1-amd64.debian.net profitbricks-build2-amd64.debian.net ; do
-	# call jenkins_master_wrapper.sh so we only need to track different ssh ports in one place...
-	/srv/jenkins/bin/jenkins_master_wrapper.sh $NODE dummy-job /srv/jenkins/bin/reproducible_info.sh > $TMPFILE_SRC
+	# call jenkins_master_wrapper.sh so we only need to track different ssh ports in one place
+	# jenkins_master_wrapper.sh needs NODE_NAME and JOB_NAME
+	export NODE_NAME=$NODE
+	export JOB_NAME=reproducible_nodes_info
+	/srv/jenkins/bin/jenkins_master_wrapper.sh /srv/jenkins/bin/reproducible_info.sh > $TMPFILE_SRC
 	for KEY in ARCH NUM_CPU CPU_MODEL DATETIME ; do
 		VALUE=$(egrep "^$KEY=" $TMPFILE_SRC | cut -d "=" -f2-)
 		if [ ! -z "$VALUE" ] ; then

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list